@@ -1,7 +1,9 @@
-;;; quail/hanja-ksc.el --- Quail-package for Korean Hanja (KSC5601)
+;;; hanja.el --- Quail-package for Korean Hanja (KSC5601)  -*-coding: iso-2022-7bit;-*-
 
-;; Copyright (C) 1997 Electrotechnical Laboratory, JAPAN.
-;; Licensed to the Free Software Foundation.
+;; Copyright (C) 1997, 2006 Free Software Foundation, Inc.
+;; Copyright (C) 1997
+;;   National Institute of Advanced Industrial Science and Technology (AIST)
+;;   Registration Number H14PRO021
 
 ;; Keywords: multilingual, input method, Korean, Hanja
 
@@ -19,28 +21,27 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
+
+;;; Synched up with: FSF 22.0.50.6
+
+;;; Commentary:
+
+;; This file defines korean-hanja keyboards:
+;; - hanja input method with hangul keyboard type 2
 
 ;;; Code:
 
 (require 'quail)
+(require 'korea-util)
 
-(defun quail-hanja-switch-to-symbol-ksc (&rest ignore)
-  "Swith to `korean-symbol' package."
-  (quail-delete-region)
-  (select-input-method "korean-symbol")
-  (throw 'quail-tag nil))
-
-
-(quail-define-package 
- "korean-hanja" "Korean" "$(C9zyS(B" t
+(quail-define-package
+ "korean-hanja" "Korean" "$(CyS(B2" t
  "2$(C9z=D(BKSC$(CySm.(B: $(Cz1SWGO4B(B $(CySm.@G(B $(Cj$@;(B $(CGQ1[(B2$(C9zcR@87N(B $(C{<usGO?)(B $(C`TwI(B"
 		      nil nil nil nil nil nil t)
 
 (quail-define-rules
- ("\\" quail-hanja-switch-to-symbol-ksc)
-
  ("rk"	"$(CJ!J"J#J$J%J&J'J(J)J*J+J,J-J.J/J0J1J2J3J4J5J6J7J8J9J:J;J<J=(B")
  ("rkr"	"$(CJ>J?J@JAJBJCJDJEJFJGJH(B")
  ("rks"	"$(CJIJJJKJLJMJNJOJPJQJRJSJTJUJVJWJXJYJZJ[J\J]J^J_J`(B")
@@ -97,7 +98,8 @@
  ("rma"	"$(CPQPRPSPTPUPVPWPXPYPZP[P\P]P^(B")
  ("rmq"	"$(CP_P`PaPbPcPdPe(B")
  ("rmd"	"$(CPfPgPhPi(B")
- ("rl"	"$(CPjPkPlPmPnPoPpPqPrPsPtPuPvPwPxPyPzP{P|P}P~Q!Q"Q#Q$Q%Q&Q'Q(Q)Q*Q+Q,Q-Q.Q/Q0Q1Q2Q3Q4Q5Q6Q7Q8Q9Q:Q;Q<Q=Q>Q?Q@QAQBQCQDQEQFQGQHQIQJQK(B")
+ ("rl"	"$(CPj(B
+  $(CPkPlPmPnPoPpPqPrPsPtPuPvPwPxPyPzP{P|P}P~Q!Q"Q#Q$Q%Q&Q'Q(Q)Q*Q+Q,Q-Q.Q/Q0Q1Q2Q3Q4Q5Q6Q7Q8Q9Q:Q;Q<Q=Q>Q?Q@QAQBQCQDQEQFQGQHQIQJQK(B")
  ("rls"	"$(CQL(B")
  ("rlf"	"$(CQMQNQOQP(B")
  ("rla"	"$(CQQ(B")
@@ -354,8 +356,8 @@
  ("wka"	"$(CmTmUmVmWmXmY(B")
  ("wkq"	"$(CmZ(B")
  ("wkd"	"$(Cm[m\m]m^m_m`mambmcmdmemfmgmhmimjmkmlmmmnmompmqmrmsmtmumvmwmxmymzm{m|m}m~n!(B")
- ("Od"	"$(Cn3n4n5n6(B")
  ("wo"	"$(Cn"n#n$n%n&n'n(n)n*n+n,n-n.n/n0n1n2(B")
+ ("wod"	"$(Cn3n4n5n6(B")
  ("wj"	"$(Cn7n8n9n:n;n<n=n>n?n@nAnBnCnDnEnFnGnHnInJnKnLnMnNnOnPnQnR(B")
  ("wjr"	"$(CnSnTnUnVnWnXnYnZn[n\n]n^n_n`nanbncndnenfngnhninjnk(B")
  ("wjs"	"$(Cnlnmnnnonpnqnrnsntnunvnwnxnynzn{n|n}n~o!o"o#o$o%o&o'o(o)o*o+o,o-o.o/o0o1o2o3o4o5o6(B")
@@ -514,3 +516,6 @@
  ("gmd"	"$(C}i(B")
  ("gml"	"$(C}j}k}l}m}n}o}p}q}r}s}t}u}v}w}x}y}z}{}|}}(B")
  ("glf"	"$(C}~(B"))
+
+;;; arch-tag: f83c4a34-ee8a-4d7f-95a2-e18816c57182
+;;; hanja.el ends here
