@@ -2,8 +2,8 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
 ;; File:         efs-vms.el
-;; Release:      $efs release: 1.23 $
-;; Version:      #Revision: 1.13 $
+;; Release:      $efs release: 1.24 $
+;; Version:      #Revision: 1.14 $
 ;; RCS:          
 ;; Description:  VMS support for efs
 ;; Authors:      Andy Norman, Joe Wells, Sandy Rutherford <sandy@itp.ethz.ch>
@@ -18,7 +18,7 @@
 (require 'efs)
 
 (defconst efs-vms-version
-  (concat (substring "$efs release: 1.23 $" 14 -2)
+  (concat (substring "$efs release: 1.24 $" 14 -2)
 	  "/"
 	  (substring "#Revision: 1.13 $" 11 -2)))
 
@@ -146,7 +146,9 @@
 	      (if (<= len 0)
 		  (setq dir nil)
 		(while (<= n len)
-		  (and (char-equal (aref dir n) ?/)
+		  (and (or (char-equal (aref dir n) ?/)
+                           (char-equal (aref dir n) ?\\)
+                           )
 		       (cond
 			((zerop n) (aset dir n ?\[))
 			((= n len) (aset dir n ?\]))
@@ -154,12 +156,10 @@
 		  (setq n (1+ n))))))
 	(concat drive dir file)))))
 
-;; It is important that this function barf for directories for which we know
-;; that we cannot possibly get a directory listing, such as "/" and "/DEV:/".
-;; This is because it saves an unnecessary FTP error, or possibly the listing
-;; might succeed, but give erroneous info. This last case is particularly
-;; likely for OS's (like MTS) for which we need to use a wildcard in order
-;; to list a directory.
+;; in vms the paths "/" and "/DEV:/" correspond to [000000] and dev:[000000]
+;; though you may not have permissions for these directories, if you do,
+;; then it mans you can explore the directory tree, rather than guess 
+;; subdirectory names
 
 (efs-defun efs-fix-dir-path vms (dir-path)
   ;; Convert path from UNIX-ish to VMS ready for a DIRectory listing.
@@ -167,11 +167,12 @@
   ;; think so, because expand-filename should have already short-circuited
   ;; them.
   (cond ((string-equal dir-path "/")
-	 (error "Cannot get listing for fictitious \"/\" directory."))
-	((string-match "^/[-A-Z0-9_$]+:/$" dir-path)
-	 (error "Cannot get listing for device."))
+	 (efs-fix-path 'vms "/000000/"))
+	((string-match "^\\(/[-A-Z0-9_$]+:/\\)$" dir-path)
+	 (efs-fix-path 'vms (concat dir-path "000000/")))
 	((efs-fix-path 'vms dir-path))))
-  
+;
+
 ;; These parsing functions are as general as possible because the syntax
 ;; of ftp listings from VMS hosts is a bit erratic. What saves us is that
 ;; the VMS filename syntax is so rigid. If they bomb on a listing in the
