@@ -1,16 +1,13 @@
-;;; ess-site.el --- user customization of ess-mode
+;;; ess-site.el --- user customization of ESS
 
 ;; Copyright (C) 1993 David M. Smith
-;; Copyright (C) 1997--2001 A.J. Rossini, R.M. Heiberger, Martin
-;; Maechler, Kurt Hornik, Rodney Sparapani.
+;; Copyright (C) 1997--2004 A.J. Rossini, Rich M. Heiberger, Martin
+;; Maechler, Kurt Hornik, Rodney Sparapani, and Stephen Eglen.
 
-;; Author: David Smith <D.M.Smith@lancaster.ac.uk>
-;; Maintainer: A.J. Rossini <rossini@biostat.washington.edu>
+;; Original Author: David Smith <D.M.Smith@lancaster.ac.uk>
 ;; Created: 12 Nov 1993
-;; Modified: $Date: 2002/05/24 23:27:37 $
-;; Version: $Revision: 1.1 $
-;; RCS: $Id: ess-site.el,v 1.1 2002/05/24 23:27:37 rossini Exp $
-;;
+;; Maintainers: ESS-core <ESS-core@stat.math.ethz.ch>
+
 ;; Keywords: start up, configuration.
 
 ;; This file is part of ESS
@@ -37,7 +34,7 @@
 ;;; directory location of this file must be supplied in
 ;;; ess-lisp-directory.	 The editing of remaining sections is
 ;;; optional.  It should then be byte-compiled, and users who wish to
-;;; use ess-mode should add the line:
+;;; use ESS should add the line:
 ;;;    (load "/PATH/TO/THIS/FILE/ess-site")
 ;;; (where /PATH/TO/THIS/FILE is the path to ess-site.elc: i.e. the
 ;;; value of ess-lisp-directory, below) to their .emacs file.
@@ -77,6 +74,9 @@
   ;; WARNING: with Emacs 20.2 (and 20.3 in one case),
   ;; =======  MUST USE ONE OF THE NON-DEFAULT SETTINGS BELOW
 
+  ;; NOTE again: MOST people should NOT change anything here !!!
+  ;; ====	 ====	     ================
+
   ;; A nice default
   (defvar ess-lisp-directory
     (if (and (boundp 'load-file-name) load-file-name)
@@ -175,27 +175,83 @@ The extension, in a file name, is the part that follows the last `.'."
 ;; This will override what Emacs thinks it can detect.
 ;;(setq ess-local-custom-available t); if custom is available, uncomment
 
+;; SJE Thu 13 May 2004
+;; Maybe ess-etc-directory should not be defcustom, since its value
+;; depends on ess-lisp-directory, and is needed by other modes that are
+;; loaded before the custom code.
+(defvar ess-etc-directory nil
+  "*Location of the ESS etc/ directory.
+The ESS etc directory stores various auxillary files that are useful
+for ESS, such as icons.")
 
-;;; (1.2) Uncomment the following 4 lines to fix the infopath, if needed.
-;;(defun add-info-path (newpath)
-;;  (setq Info-default-directory-list
-;;	(cons (expand-file-name newpath) Info-default-directory-list)))
-;;(add-info-path (concat ess-lisp-directory "/../doc/"))
+(defvar ess-etc-directory-list
+  '("../etc/" "../etc/ess/" "../../etc/ess/" "./etc/")
+  "*List of directories, relative to `ess-lisp-directory', to search for etc.")
 
+(while (and (listp ess-etc-directory-list) (consp ess-etc-directory-list))
+    (setq ess-etc-directory 
+	(expand-file-name (concat ess-lisp-directory "/"
+	    (car ess-etc-directory-list))))
+    (if (file-directory-p ess-etc-directory) 
+	(setq ess-etc-directory-list nil)
+	(setq ess-etc-directory nil)
+	(setq ess-etc-directory-list (cdr ess-etc-directory-list))
+    (when (null ess-etc-directory-list)
+      (beep 0) (beep 0)
+      (message (concat
+	    "ERROR:ess-site.el:ess-etc-directory\n"
+	    "Relative to ess-lisp-directory\n"
+	    "At least one of ../etc, ../etc/ess, ../../etc/ess must exist!"))
+      (sit-for 4))))
+
+(defvar ess-info-directory nil
+  "*Location of the ESS info/ directory.
+The ESS info directory stores the ESS info files.")
+
+;;(1.2) If ess.info is not found, then ess-lisp-directory/../doc/info is added
+;; resurrecting Stephen's version with a bug-fix & xemacs compatibility
+(unless
+    (member t
+	(mapcar 'file-exists-p
+	    (mapcar '(lambda (x) (concat (file-name-as-directory x) "ess.info"))
+		(if (featurep 'xemacs)
+		    Info-directory-list Info-default-directory-list))))
+    (add-to-list (if (featurep 'xemacs)
+		     'Info-directory-list 'Info-default-directory-list)
+		     (expand-file-name
+			 (concat ess-lisp-directory "/../doc/info/"))))
 
 ;;; (1.3) Files ending in .q and .S are considered to be S source files
 ;;; Files ending in .St are considered to be S transcript files
+;;;
 ;;; NB: in standard Emacs, files ending in .s are assembler files.  If you
-;;; want to use assembler, comment the appropriate
-;;; line below.
+;;; want to use assembler, you can comment the appropriate line below.  Of
+;;; course, different users will want different modes.  If a user wants to
+;;; restore default the default modes for assembly file extensions, the
+;;; following can go into ~/.emacs:
+;;;
+;;;  (add-hook 'ess-mode-hook 'ess-restore-asm-extns)
+;;;  (add-hook 'inferior-ess-mode-hook 'ess-restore-asm-extns)
 
 (autoload 'Rd-mode "essddr" "Major mode for editing R documentation." t)
 
-;; This fails in Emacs.  How can it be done simply?  Should it be
-;; done?  It works in XEmacs.
-;;    ;; get rid of assembler mode.
-;;    (set auto-mode-alist (remassoc "\\.[sS]\\'" auto-mode-alist))
-;; Our current solution is as follows.
+;; This is thanks to  Ed L Cashin <ecashin@uga.edu>, 03 Mar 2004 :
+(defun ess-restore-asm-extns ()
+  "take away the S-Plus mode association for .s and .S files added by ESS
+Putting the following in ~/.emacs restores emacs' default association
+between .s or .S files and assembly mode.
+
+  (add-hook 'ess-mode-hook 'ess-restore-asm-extns)
+  (add-hook 'inferior-ess-mode-hook 'ess-restore-asm-extns)
+"
+  (interactive)
+  (if (assoc "\\.[qsS]\\'" auto-mode-alist)
+      (progn
+	(setq auto-mode-alist
+	      (remassoc "\\.[qsS]\\'" auto-mode-alist))
+	;; put .q extention back
+	;; (add-to-list is in xemacs and GNU emacs)
+	(add-to-list 'auto-mode-alist '("\\.q\\'" . S-mode)))))
 
 ;; Be careful when editing the following. MISTAKES WILL RESULT IN
 ;; *.sty BEING TREATED AS ESS[S], rather than LaTeX-mode!
@@ -204,20 +260,21 @@ The extension, in a file name, is the part that follows the last `.'."
   (setq auto-mode-alist
 	(append
 	 '(("\\.sp\\'"	  . S-mode) ;; re: Don MacQueen <macq@llnl.gov>
-	   ("\\.[qsS]\\'" . S-mode) ;; q,s,S
+	   ("\\.[qsS]\\'" . S-mode) ;; q,s,S [see ess-restore-asm-extns above!]
 	   ("\\.ssc\\'"	  . S-mode) ;; Splus 4.x script files.
 	   ("\\.[rR]\\'"  . R-mode)
+	   ("\\.[rR]nw\\'"  . Rnw-mode)
 	   ("\\.[rR]profile\\'" . R-mode)
+	   ("NAMESPACE\\'" . R-mode)
 	   ("\\.omg\\'"         . omegahat-mode)
 	   ("\\.hat\\'"         . omegahat-mode) ;; Duncan's pref'd...
 	   ("\\.lsp\\'"		. XLS-mode)
 	   ("\\.do\\'"		. STA-mode)
 	   ("\\.ado\\'"		. STA-mode)
-	   ("\\.sas\\'"		. SAS-mode)
-	   ("\\.SAS\\'"		. SAS-mode)
-	   ;;("\\.lst\\'"		. SAS-listing-mode);sasl
-	   ;; Too many *.log files, not only SAS :
-	   ;;("\\.log\\'"	. SAS-log-mode);sasl
+	   ("\\.[Ss][Aa][Ss]\\'"	. SAS-mode)
+	   ;; Many .log/.lst files, not just SAS
+	   ;;("\\.log\\'"	. SAS-log-mode)
+	   ;;("\\.lst\\'"	. SAS-listing-mode)
 	   ("\\.[Ss]t\\'"	. S-transcript-mode)
 	   ("\\.[Ss]out"	. S-transcript-mode)
 	   ("\\.[Rr]t\\'"	. R-transcript-mode)
@@ -252,6 +309,7 @@ The extension, in a file name, is the part that follows the last `.'."
 ;;(setq-default inferior-S+6-program-name "Splus6")
 ;;(setq-default inferior-R-program-name "R")	  ; unix systems
 ;;(setq-default inferior-R-program-name "Rterm")  ; msdos systems
+;;(setq-default inferior-R-program-name "C:\\Program Files\\R\rw1081\\bin\\Rterm.exe")  ; msdos systems
 ;;(setq-default inferior-XLS-program-name "xlispstat")
 ;;(setq-default inferior-ARC-program-name "arc")
 ;;(setq-default inferior-VST-program-name "vista")
@@ -288,7 +346,7 @@ The extension, in a file name, is the part that follows the last `.'."
 ;;; These commands are for running the PC version of Sqpe of S+4 and
 ;;; S+6 in an emacs buffer, using the same technology as ESS uses for
 ;;; Unix S-Plus.  Interactive graphics are unavailable in this mode.
-;;; See essd-sp4.el or essdsp6w.el
+;;; See essd-sp4.el or essd-sp6w.el
 
 ;;; These are the defaults.  Change them here if the defaults don't work.
 ;;; Use the 8.3 version of the pathname because embedded blanks will cause
@@ -314,7 +372,7 @@ The extension, in a file name, is the part that follows the last `.'."
 ;;; control to the user.  On a 300 MHz machine with 96MB of RAM the
 ;;; delay is 60 seconds.  On a ???? MHz machine with 523MB the delay is
 ;;; 10 seconds.  The user may need to adjust this number.
-(defvar ess-S+6-startup-delay 60
+(defvar ess-S+6-startup-delay 15 ;; <- 2005-01-03; MM
 "*Number of seconds to wait for the Commands window to appear before
 sending `inferior-ess-language-start' to S-Plus.")
 
@@ -340,20 +398,24 @@ sending `inferior-ess-language-start' to S-Plus.")
 
 (ess-message "[ess-site:] Before requiring dialect 'essd-** ....")
 (ess-message "[ess-site:] require 'essd-r ...")
-(require 'essd-r)    ;; S and common variants
-(ess-message "[ess-site:] require 'essd-s4 ...")
-(require 'essd-s4)
+(require 'essd-r)    ;; R
+;; (ess-message "[ess-site:] require 'essd-s4 ...")
+;; (require 'essd-s4) ; has become VERY RARE ..
+
 ;;(ess-message "[ess-site:] require 'essd-s3 ...")
 ;;(require 'essd-s3)  ; THIS IS RARE.  You probably do not have this.
+
+;; "sp" refers to S-PLUS (MathSoft/StatSci/Insightful):
 (ess-message "[ess-site:] require 'essd-sp3 ...")
-(require 'essd-sp3)  ;; "sp" refers to S-PLUS (MathSoft/StatSci).
+(require 'essd-sp3)
 
 (if ess-microsoft-p
     (progn
       (ess-message "[ess-site:] require 'essd-sp4 ...")
       (require 'essd-sp4)
-      (ess-message "[ess-site:] require 'essdsp6w ...")
-      (require 'essdsp6w))
+      (ess-message "[ess-site:] require 'essd-sp6w ...")
+      (require 'essd-sp6w))
+  ;; else: decent OS
   (ess-message "[ess-site:] require 'essd-sp5 ...")
   (require 'essd-sp5)
   (ess-message "[ess-site:] require 'essd-sp6 ...")
@@ -369,11 +431,6 @@ sending `inferior-ess-language-start' to S-Plus.")
 (require 'essd-arc)  ;; Arc
 (ess-message "[ess-site:] require 'essd-sas ...")
 (require 'essd-sas)
-(save-excursion                           ;;workaround for ess-smart-underscore
-  (switch-to-buffer "unlikely-name.sas")  ;;workaround for ess-smart-underscore
-  (sas-mode)                              ;;workaround for ess-smart-underscore
-  (define-key sas-mode-local-map "_" nil) ;;workaround for ess-smart-underscore
-  (kill-buffer "unlikely-name.sas"))      ;;workaround for ess-smart-underscore
 (ess-message "[ess-site:] require 'essd-els ...")
 (require 'essd-els)  ;; S-elsewhere, on another machine by telnet
 (ess-message "[ess-site:] require 'essd-omg ...")
@@ -386,25 +443,27 @@ sending `inferior-ess-language-start' to S-Plus.")
 	   ess-customize-alist))
 
 ;;; (1.7) Literate Data Analysis
-;(require 'ess-noweb)
-;(setq auto-mode-alist
-;      (append
-;       '(("\\.nw\\'"          . noweb-mode)) ;; Literate Data Analysis
-;       auto-mode-alist))
+(require 'ess-noweb)
+(require 'ess-swv); for Sweave
 
 ;; ALWAYS:
-(require 'ess)
+(require 'ess); -> loads ess-cust.el and more
 
 (ess-write-to-dribble-buffer
    (format "[ess-site.el _2_]: ess-customize-alist=%s \n"
 	   ess-customize-alist))
 
-
 ;; (1.8) Speedbar and mouse
 
 (require 'ess-menu)
 (require 'ess-mous)
 
+;; (1.9) Toolbar support
+
+;; To remove toolbar support under ESS, either comment-out 
+;; (require 'ess-toolbar) below, or add "(setq ess-use-toolbar nil)"
+;; to your .emacs before (require 'ess-site).
+(require 'ess-toolbar)
 
 ;;; 2. Site Specific setup
 ;;;; ===============================================
@@ -426,6 +485,9 @@ sending `inferior-ess-language-start' to S-Plus.")
 (autoload 'ess-transcript-mode "ess-trns"
   "Major mode for editing S transcript files." t)
 
+(autoload 'ess-rdired "ess-rdired"
+  "View *R* objects in a dired-like buffer." t)
+
 ;;; On a PC, the default is S+6.
 ;; Elsewhere (unix and linux) the default is S+6
 (cond (ess-microsoft-p ; MS-Windows
@@ -442,9 +504,7 @@ sending `inferior-ess-language-start' to S-Plus.")
       (t				; Other Unixen
        (fset 'S 'S+6)
        (fset 's-mode 'S+6-mode)
-       (fset 's-transcript-mode 'S+6-transcript-mode))
-)
-
+       (fset 's-transcript-mode 'S+6-transcript-mode)))
 
 
 ;;;;* Alias S-mode to s-mode
@@ -458,7 +518,38 @@ sending `inferior-ess-language-start' to S-Plus.")
 (fset 'S-transcript-mode 's-transcript-mode)
 (fset 'S-mode 's-mode)
 
+;;; Create functions for calling older versions of R and Sqpe.
+(let ( (ess-sqpe-versions-created)
+       (ess-rterm-versions-created)
+       (ess-r-versions-created)
+       (ess-versions-created)
+       )
+  (if ess-microsoft-p
+      (progn
+	(setq ess-sqpe-versions-created
+	      (ess-sqpe-versions-create))   ;; use ess-SHOME-versions
+	(setq ess-rterm-versions (ess-find-rterm))
+	(setq ess-rterm-versions-created
+	      (ess-rterm-versions-create))) ;; use ess-rterm-versions
+    (setq ess-r-versions-created
+	  (ess-r-versions-create)))	    ;; use ess-r-versions
 
+  ;; Add the new defuns, if any, to the menu.
+  ;; Check that each variable exists, before adding.
+  ;; e.g. ess-sqpe-versions-created will not be created on Unix.
+  (setq ess-versions-created
+	(ess-flatten-list
+	 (mapcar (lambda(x) (if (boundp x) (symbol-value x) nil))
+		 '(ess-r-versions-created
+		   ess-rterm-versions-created ess-sqpe-versions-created))))
+
+  (when ess-versions-created
+    ;; new-menu will be a list of 3-vectors, of the form:
+    ;; ["R-1.8.1" R-1.8.1 t]
+    (let (( new-menu (mapcar '(lambda(x) (vector x (intern x) t))
+			     ess-versions-created)))
+    (easy-menu-add-item ess-mode-menu '("Start Process")
+			(cons "Other" new-menu)))))
 
 
 ;;; 3. Customization (and commented out examples) for your site
@@ -470,13 +561,12 @@ sending `inferior-ess-language-start' to S-Plus.")
 ;;; process.  To number all processes, uncomment the next line.
 ;;(setq ess-plain-first-buffername nil)
 
-
-
 ;;; (3.1) Font-lock
 ;; The following two expressions automatically enable font-lock-mode
 ;; for ess-mode and inferior-ess-mode buffers.
 
-;; XEmacs has font-lock for ttys, as well.  So we need a better check!
+;; FIXME: XEmacs and Emacs 21.x has font-lock for ttys, as well.
+;; So we need a better check! [or do this unconditionally -working everywhere ??]
 (if window-system
     (progn
       (add-hook 'ess-mode-hook 'turn-on-font-lock t)
@@ -520,7 +610,7 @@ sending `inferior-ess-language-start' to S-Plus.")
 ;;; (3.4) ess-ask-for-ess-directory
 ;;; If t, will ask for the directory to use.  If nil, assumes the
 ;;; default (usually, the users home directory...).
-(setq ess-ask-for-ess-directory t)
+;;now rather in ./ess-cust.el : (setq ess-ask-for-ess-directory t)
 
 ;;; (3.5) ess-directory default	 (correlated with above)
 ;;; The default location for running the subprocess is configurable.
@@ -569,66 +659,34 @@ sending `inferior-ess-language-start' to S-Plus.")
 ;;;   1. Editing SAS-mode files.
 ;;;   1a. Default: TAB is bound to sas-indent-line.
 ;;;       Current line is correctly indented as SAS code.  Equivalent to
-;;;(setq ess-sas-edit-keys-toggle 0) ;; default TAB in sas-mode
+;;;(setq ess-sas-edit-keys-toggle nil) ;; default TAB in sas-mode
 ;;;   1b. Optional: TAB is bound to tab-to-tab-stop and inserts up to 4
 ;;;       columns at a time.  C-TAB moves backwards and deletes characters
 ;;;       up to 4 columns at a time.
 ;;;       Uncomment the following line for the optional behavior.
-;;;(setq ess-sas-edit-keys-toggle 1)   ;; optional TAB and C-TAB in sas-mode
-;;;   Use the function call (ess-sas-edit-keys-toggle 0)
-;;;   or                    (ess-sas-edit-keys-toggle 1)
+;;;(setq ess-sas-edit-keys-toggle t)   ;; optional TAB and C-TAB in sas-mode
+;;;   Use the function call (ess-sas-edit-keys-toggle)
 ;;;   to change the setting after the first SAS-mode buffer has been created.
-;;;   1c. You can also define C-TAB in all modes by specifying either
-;;;(setq ess-sas-global-unix-keys t) ;; optional C-TAB bound in all modes
-;;;(setq ess-sas-global-pc-keys t)   ;; optional C-TAB bound in all modes
-;;;       See below.
+;;;   1c. You can also define C-TAB in all modes by Option 2b (below).
 ;;;
 ;;;   2. Managing submitted SAS jobs with function keys.
-;;;   2a. Default: Function keys retain their global bindings.
-;;;   2b. Options: Uncomment at most one of the following four lines.
-;;;(setq ess-sas-local-unix-keys t)  ;; [f2]--[f8] bound in sas-mode and related modes
-;;;(setq ess-sas-local-pc-keys t)    ;; [f2]--[f8] bound in sas-mode and related modes
-;;;(setq ess-sas-global-unix-keys t) ;; [f2]--[f8] bound in all modes
-;;;(setq ess-sas-global-pc-keys t)   ;; [f2]--[f8] bound in all modes
+;;;   2a. Default: To define the function keys in ESS[SAS] mode only,
+;;;   uncomment at most one of the following two lines.
+;;;(setq ess-sas-local-unix-keys t)  ;; F2-F12 bound in ESS[SAS] mode
+;;;(setq ess-sas-local-pc-keys t)    ;; F2-F12 bound in ESS[SAS] mode
+;;;
+;;;   2b. Options: To define the function keys in all modes,
+;;;   uncomment at most one of the following two lines.
+;;;(setq ess-sas-global-unix-keys t) ;; F2-F12 bound in all modes
+;;;(setq ess-sas-global-pc-keys t)   ;; F2-F12 bound in all modes
 ;;;
 ;;;   3. If it is more convenient to have "*Async Shell Command*"
 ;;;      in same-window-buffer-names, then uncomment the following line
 ;;;(ess-same-window-async)
 ;;;
-;;;   4. As of 5.1.19, a new and improved syntax highlighting scheme for .sas and .log
-;;;	 files is available (press f10 to toggle between modes in .log).  If you are
-;;;      using XEmacs v. 20.x, then you need this as well, since it works around a
-;;;      problem with make-regexp.el.  Uncomment the next line for this feature:
-;;;(setq ess-sas-run-make-regexp nil)
-
-
-;(defvar sas-require-confirmation t
-;  "*Require confirmation when revisiting sas-output which has changed on disk.")
-;;; added sas-program 4/29/94.	user can specify a different version of sas.
 ;;;(defvar sas-program "sas" "*Name of program which runs sas.")
-;;(defvar sas-pre-run-hook nil
-;;  "Hook to execute prior to running SAS vis submit-sas.")
-;;(defvar sas-options-string ""
-;;  "*Options to be passed to sas as if typed on the command line.")
-;;(defvar sas-indent-width 4 "*Amount to indent sas statements")
-;;(defvar sas-notify t "*Beep and display message when job is done?")  ;; added 4/7/94
-;;(defvar sas-error-notify t
-;;  "*If sas-notify is t, then indicate errors in log file upon completion")
-;;;; added 5/2/94
-;;(defvar sas-get-options nil "Options to be passed to SAS in sas-get-dataset")
-;;(defvar sas-get-options-history nil "History list of Options passed to SAS in sas-get-dataset")
-;;(defvar sas-page-number-max-line 3
-;;  "*Number of lines from the page break in which to search for the page number")
-;;(defvar sas-indent-ignore-comment "*"
-;;  "*Comments with start with this string are ignored in indentation.")
-;;(defvar sas-notify-popup nil
-;;  "*If t (and sas-notify is also t), causes emacs to create a
-;;popup window when the SAS job is finished.")
-;;(defvar sas-tmp-libname "_tmp_" "*Libname to use for sas-get-dataset.")
-
-;;; 5.0 Noweb and Literate Data Analysis configuration
-
-;; already above [1.7]: (require 'ess-noweb)
+;;;
+;;;(defvar sas-indent-width 4 "*Amount to indent sas statements")
 
  ; Local variables section
 
