@@ -1,6 +1,6 @@
 ;;; hm--html-configuration.el - Configurationfile for the html-mode
 ;;;
-;;; $Id: hm--html-configuration.el,v 6.21 2000/10/06 08:45:59 youngs Exp $
+;;; $Id: hm--html-configuration.el,v 6.24 2007-09-04 09:02:54 didierv Exp $
 ;;;
 ;;; Copyright (C) 1993 - 1997  Heiko Muenkel
 ;;; email: muenkel@tnt.uni-hannover.de
@@ -19,7 +19,7 @@
 ;;;  along with this program; if not, write to the Free Software
 ;;;  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 ;;;
-;;; 
+;;;
 ;;; Description:
 ;;;
 ;;;	This file is for the system wide configuration of the html mode.
@@ -29,12 +29,12 @@
 ;;;	All settings in this file are done with defvar's, therefore
 ;;;	you could overwrite them also with the function setq in your
 ;;;	.emacs or default.el and so on.
-;;; 
-;;; Installation: 
-;;;   
+;;;
+;;; Installation:
+;;;
 ;;;	Put this file in one of your lisp load path directories or
 ;;;	set the environment variable HTML_CONFIG_FILE to this file.
-;;;	For example: 
+;;;	For example:
 ;;;       setenv HTML_CONFIG_FILE "~/data/hm--htm-environment.el"
 ;;;	  if you have put this file in the directory "~/data/"
 ;;;
@@ -90,7 +90,7 @@ the creation and change dates, the HTML doctype and the meta element."
 (defcustom hm--html-user-config-file nil
   "*The location of the users config file.
 This variable will only be used, if no environment variable
-\"HTML_USER_CONFIG_FILE\" is set. 
+\"HTML_USER_CONFIG_FILE\" is set.
 Example value: \"~/.hm--html-configuration.el\".
 
 If this is set to nil and no \"HTML_USER_CONFIG_FILE\" is set,
@@ -98,7 +98,7 @@ then the file ~/.hm--html-configuration.el will be used. In this case
 also the variable `init-file-user' will be respected."
   :group 'hm--html-files
   :type '(choice (const :tag "No user config file" :value nil)
-		 (const :tag "~/.hm--html-configuration.el" 
+		 (const :tag "~/.hm--html-configuration.el"
 			:value "~/.hm--html-configuration.el")
 		 file))
 
@@ -116,7 +116,7 @@ This variable will only be used, if no environment variable
   "*t    : Use the HTML expert popup menu,
 nil : Use the HTML novice (simple) menu.
 
-NOTE: In the Emacs 19 you should set this variable only before 
+NOTE: In the Emacs 19 you should set this variable only before
       loading the mode."
   :group 'hm--html-menus
   :type '(choice (const :tag "Use Expert Popup Menu" :value t)
@@ -124,7 +124,7 @@ NOTE: In the Emacs 19 you should set this variable only before
 
 ;;; Your Signature
 
-(defcustom hm--html-signature-file nil 
+(defcustom hm--html-signature-file nil
   "*Your Signature file.
 For example: \"http://www.tnt.uni-hannover.de:80/data/info/www/tnt/info/tnt/whois/muenkel.html\"."
   :group 'hm--html-document-information
@@ -191,7 +191,7 @@ For example: \"http://www.tnt.uni-hannover.de:80/data/info/www/tnt/info/tnt/whoi
   :group 'hm--html-links
   :type 'string)
 
-(defcustom hm--html-wais-servername:port-alist 
+(defcustom hm--html-wais-servername:port-alist
   '(("wais.tnt.uni-hannover.de:210")
     ("daedalus.tnt.uni-hannover.de:21408")
     ("ikarus.tnt.uni-hannover.de:21401"))
@@ -433,7 +433,7 @@ this alist."
 These commands needs no parameter."
   :group 'hm--html-links
   :type '(repeat string))
-	
+
 (defcustom hm--html-server-side-include-command-with-parameter-alist
   '(("/usr/bin/man")
     ("/usr/bin/finger")
@@ -443,22 +443,22 @@ These commands needs no parameter."
 These commands needs parameters."
   :group 'hm--html-links
   :type '(repeat string))
-	
+
 
 ;;; Alist with URL'S for FORMS and IMAGE tags
 
-(defcustom hm--html-url-alist 
+(defcustom hm--html-url-alist
   (list
    '("http://hoohoo.ncsa.uiuc.edu/htbin-post/post-query"
      POST)
    '("http://hoohoo.ncsa.uiuc.edu/htbin/query"
      GET)
-   (list 
-    (concat "http://" 
+   (list
+    (concat "http://"
 	    hm--html-favorite-http-server-host-name
 	    "/")
     'IMAGE))
-  "*Alist with URL's for FORMS and IMAGE tags. 
+  "*Alist with URL's for FORMS and IMAGE tags.
 The cdr of each list contains symbols, which specify the use of the
 URL."
   :group 'hm--html-links
@@ -528,7 +528,7 @@ which is distributed with the package hm--html-menus."
 (defcustom hm--html-delete-wrong-path-prefix '("/tmp_mnt" "/phys/[^/]+")
   "If non nil, it specifies path-prefixes, which should be deleted in paths.
 The Sun automounter adds a temporary prefix to the automounted directories
- (At our site the prefix is /tmp_mnt). But you can't select such a path, if 
+ (At our site the prefix is /tmp_mnt). But you can't select such a path, if
 the automounter has currently not mounted the directory and so you can't
 follow a html-link, which consists of such a path. To overcome this behaviour,
 you can set this variable to the prefix (eg. \"/tmp_mnt\"). After that, the
@@ -562,14 +562,14 @@ nil => No automatic update of the date."
 ;;; variable hm--html-log-date-format instead
 
 ;(defcustom hm--hmtl-include-time-after-date nil
-;  "*t   => The time of day will be appended to the date 
-;in the created and changed comment lines, as well as in the 
+;  "*t   => The time of day will be appended to the date
+;in the created and changed comment lines, as well as in the
 ;visible modified line if these lines are present; the time
 ;will never be appended to the date in the title. The separator
 ;between date and title is defined with hm--html-date-time-separator."
 ;  :group 'hm--html-document-information
 ;  :type 'boolean)
- 
+
 ;(defcustom hm--html-date-time-separator " at "
 ;  "The value of the separator between date and time in the
 ;created and modified comment lines and in the visible modified
@@ -583,175 +583,175 @@ WARNING: Don't use the character `<' in this string!
 The log lines are the lines with the created and changed comments.
 The format is used as argument of the function `format-time-string'.
     `%a'
-          This stands for the abbreviated name of the day of week.
+	  This stands for the abbreviated name of the day of week.
     `%A'
-          This stands for the full name of the day of week.
+	  This stands for the full name of the day of week.
     `%b'
-          This stands for the abbreviated name of the month.
+	  This stands for the abbreviated name of the month.
     `%B'
-          This stands for the full name of the month.
+	  This stands for the full name of the month.
     `%c'
-          This is a synonym for `%x %X'.
+	  This is a synonym for `%x %X'.
     `%C'
-          This has a locale-specific meaning.  In the default locale
-          (named C), it is equivalent to `%A, %B %e, %Y'.
+	  This has a locale-specific meaning.  In the default locale
+	  (named C), it is equivalent to `%A, %B %e, %Y'.
     `%d'
-          This stands for the day of month, zero-padded.
+	  This stands for the day of month, zero-padded.
     `%D'
-          This is a synonym for `%m/%d/%y'.
+	  This is a synonym for `%m/%d/%y'.
     `%e'
-          This stands for the day of month, blank-padded.
+	  This stands for the day of month, blank-padded.
     `%h'
-          This is a synonym for `%b'.
+	  This is a synonym for `%b'.
     `%H'
-          This stands for the hour (00-23).
+	  This stands for the hour (00-23).
     `%I'
-          This stands for the hour (00-12).
+	  This stands for the hour (00-12).
     `%j'
-          This stands for the day of the year (001-366).
+	  This stands for the day of the year (001-366).
     `%k'
-          This stands for the hour (0-23), blank padded.
+	  This stands for the hour (0-23), blank padded.
     `%l'
-          This stands for the hour (1-12), blank padded.
+	  This stands for the hour (1-12), blank padded.
     `%m'
-          This stands for the month (01-12).
+	  This stands for the month (01-12).
     `%M'
-          This stands for the minute (00-59).
+	  This stands for the minute (00-59).
     `%n'
-          This stands for a newline.
+	  This stands for a newline.
     `%p'
-          This stands for `AM' or `PM', as appropriate.
+	  This stands for `AM' or `PM', as appropriate.
     `%r'
-          This is a synonym for `%I:%M:%S %p'.
+	  This is a synonym for `%I:%M:%S %p'.
     `%R'
-          This is a synonym for `%H:%M'.
+	  This is a synonym for `%H:%M'.
     `%S'
-          This stands for the seconds (00-60).
+	  This stands for the seconds (00-60).
     `%t'
-          This stands for a tab character.
+	  This stands for a tab character.
     `%T'
-          This is a synonym for `%H:%M:%S'.
+	  This is a synonym for `%H:%M:%S'.
     `%U'
-          This stands for the week of the year (01-52), assuming that
-          weeks start on Sunday.
+	  This stands for the week of the year (01-52), assuming that
+	  weeks start on Sunday.
     `%w'
-          This stands for the numeric day of week (0-6).  Sunday is day
-          0.
+	  This stands for the numeric day of week (0-6).  Sunday is day
+	  0.
     `%W'
-          This stands for the week of the year (01-52), assuming that
-          weeks start on Monday.
+	  This stands for the week of the year (01-52), assuming that
+	  weeks start on Monday.
     `%x'
-          This has a locale-specific meaning.  In the default locale
-          (named C), it is equivalent to `%D'.
+	  This has a locale-specific meaning.  In the default locale
+	  (named C), it is equivalent to `%D'.
     `%X'
-          This has a locale-specific meaning.  In the default locale
-          (named C), it is equivalent to `%T'.
+	  This has a locale-specific meaning.  In the default locale
+	  (named C), it is equivalent to `%T'.
     `%y'
-          This stands for the year without century (00-99).
+	  This stands for the year without century (00-99).
     `%Y'
-          This stands for the year with century.
+	  This stands for the year with century.
     `%Z'
-          This stands for the time zone abbreviation."
+	  This stands for the time zone abbreviation."
   :group 'hm--html-document-information
   :type '(choice (const :tag "22-Feb-1997" :value "%d-%b-%Y")
 		 (const :tag "22.02.97" :value "%d.%m.%y")
 		 (const :tag "02/22/97" :value "%D")
-                 (const :tag "97-02-22" :value "%y-%m-%d")
-                 (const :tag "22-Feb-1997 22:30:07" :value "%d-%b-%Y %T")
+		 (const :tag "97-02-22" :value "%y-%m-%d")
+		 (const :tag "22-Feb-1997 22:30:07" :value "%d-%b-%Y %T")
 		 (const :tag "22-Feb-1997 22:30" :value "%d-%b-%Y %R")
 		 (const :tag "22-Feb-1997 at 22:30" :value "%d-%b-%Y at %R")
-                 (const :tag "22.02.97 22:30:07" :value "%d.%m.%y %T")
+		 (const :tag "22.02.97 22:30:07" :value "%d.%m.%y %T")
 		 (const :tag "02/22/97 22:30:07" :value "%D %T")
 		 (const :tag "02/22/97 10:30:07 PM" :value "%D %r")
-                 (const :tag "97-02-22 22:30:07" :value "%y-%m-%d %T")
-                 string))
+		 (const :tag "97-02-22 22:30:07" :value "%y-%m-%d %T")
+		 string))
 
 (defcustom hm--html-title-date-format "%d-%b-%Y"
   "Default output format for date and time in the title and main header line.
 WARNING: Don't use the character `<' in this string!
 The format is used as argument of the function `format-time-string'.
     `%a'
-          This stands for the abbreviated name of the day of week.
+	  This stands for the abbreviated name of the day of week.
     `%A'
-          This stands for the full name of the day of week.
+	  This stands for the full name of the day of week.
     `%b'
-          This stands for the abbreviated name of the month.
+	  This stands for the abbreviated name of the month.
     `%B'
-          This stands for the full name of the month.
+	  This stands for the full name of the month.
     `%c'
-          This is a synonym for `%x %X'.
+	  This is a synonym for `%x %X'.
     `%C'
-          This has a locale-specific meaning.  In the default locale
-          (named C), it is equivalent to `%A, %B %e, %Y'.
+	  This has a locale-specific meaning.  In the default locale
+	  (named C), it is equivalent to `%A, %B %e, %Y'.
     `%d'
-          This stands for the day of month, zero-padded.
+	  This stands for the day of month, zero-padded.
     `%D'
-          This is a synonym for `%m/%d/%y'.
+	  This is a synonym for `%m/%d/%y'.
     `%e'
-          This stands for the day of month, blank-padded.
+	  This stands for the day of month, blank-padded.
     `%h'
-          This is a synonym for `%b'.
+	  This is a synonym for `%b'.
     `%H'
-          This stands for the hour (00-23).
+	  This stands for the hour (00-23).
     `%I'
-          This stands for the hour (00-12).
+	  This stands for the hour (00-12).
     `%j'
-          This stands for the day of the year (001-366).
+	  This stands for the day of the year (001-366).
     `%k'
-          This stands for the hour (0-23), blank padded.
+	  This stands for the hour (0-23), blank padded.
     `%l'
-          This stands for the hour (1-12), blank padded.
+	  This stands for the hour (1-12), blank padded.
     `%m'
-          This stands for the month (01-12).
+	  This stands for the month (01-12).
     `%M'
-          This stands for the minute (00-59).
+	  This stands for the minute (00-59).
     `%n'
-          This stands for a newline.
+	  This stands for a newline.
     `%p'
-          This stands for `AM' or `PM', as appropriate.
+	  This stands for `AM' or `PM', as appropriate.
     `%r'
-          This is a synonym for `%I:%M:%S %p'.
+	  This is a synonym for `%I:%M:%S %p'.
     `%R'
-          This is a synonym for `%H:%M'.
+	  This is a synonym for `%H:%M'.
     `%S'
-          This stands for the seconds (00-60).
+	  This stands for the seconds (00-60).
     `%t'
-          This stands for a tab character.
+	  This stands for a tab character.
     `%T'
-          This is a synonym for `%H:%M:%S'.
+	  This is a synonym for `%H:%M:%S'.
     `%U'
-          This stands for the week of the year (01-52), assuming that
-          weeks start on Sunday.
+	  This stands for the week of the year (01-52), assuming that
+	  weeks start on Sunday.
     `%w'
-          This stands for the numeric day of week (0-6).  Sunday is day
-          0.
+	  This stands for the numeric day of week (0-6).  Sunday is day
+	  0.
     `%W'
-          This stands for the week of the year (01-52), assuming that
-          weeks start on Monday.
+	  This stands for the week of the year (01-52), assuming that
+	  weeks start on Monday.
     `%x'
-          This has a locale-specific meaning.  In the default locale
-          (named C), it is equivalent to `%D'.
+	  This has a locale-specific meaning.  In the default locale
+	  (named C), it is equivalent to `%D'.
     `%X'
-          This has a locale-specific meaning.  In the default locale
-          (named C), it is equivalent to `%T'.
+	  This has a locale-specific meaning.  In the default locale
+	  (named C), it is equivalent to `%T'.
     `%y'
-          This stands for the year without century (00-99).
+	  This stands for the year without century (00-99).
     `%Y'
-          This stands for the year with century.
+	  This stands for the year with century.
     `%Z'
-          This stands for the time zone abbreviation."
+	  This stands for the time zone abbreviation."
   :group 'hm--html-document-information
   :type '(choice (const :tag "22-Feb-1997" :value "%d-%b-%Y")
 		 (const :tag "22.02.97" :value "%d.%m.%y")
 		 (const :tag "02/22/97" :value "%D")
-                 (const :tag "97-02-22" :value "%y-%m-%d")
-                 (const :tag "22-Feb-1997 22:30:07" :value "%d-%b-%Y %T")
+		 (const :tag "97-02-22" :value "%y-%m-%d")
+		 (const :tag "22-Feb-1997 22:30:07" :value "%d-%b-%Y %T")
 		 (const :tag "22-Feb-1997 22:30" :value "%d-%b-%Y %R")
-                 (const :tag "22.02.97 22:30:07" :value "%d.%m.%y %T")
+		 (const :tag "22.02.97 22:30:07" :value "%d.%m.%y %T")
 		 (const :tag "02/22/97 22:30:07" :value "%D %T")
 		 (const :tag "02/22/97 10:30:07 PM" :value "%D %r")
-                 (const :tag "97-02-22 22:30:07" :value "%y-%m-%d %T")
-                 string))
+		 (const :tag "97-02-22 22:30:07" :value "%y-%m-%d %T")
+		 string))
 
 (defcustom hm--html-automatic-changed-comment t
   "*t   => A \"changed comment\" line will be added before filesaving.
@@ -845,7 +845,7 @@ The search will be done from the end to the beginning."
 
 (defcustom hm--html-bind-latin-1-char-entities t
   "Set this to nil, if you don't want to use the ISO Latin 1 character entities.
-This is only useful, if `hm--html-use-old-keymap' is set to nil. It is only 
+This is only useful, if `hm--html-use-old-keymap' is set to nil. It is only
 used during loading the html package the first time."
   :group 'hm--html-keys
   :type 'boolean)
@@ -879,7 +879,7 @@ drag and drop."
   "The action list for the destination mode `hm--html-mode'.
 Look at the description of the variable idd-actions."
   :group 'hm--html-keys
-  :type 'list)
+  :type 'sexp)
 
 
 ;;; The font lock keywords
@@ -890,7 +890,7 @@ Look at the description of the variable idd-actions."
    '("<[^>]*>" . font-lock-keyword-face)
 ;   '("<[^>=]*href[ \t\n]*=[ \t\n]*\"\\([^\"]*\\)\"" 1 font-lock-string-face t)
 ;   '("<[^>=]src[ \t\n]*=[ \t\n]*\"\\([^\"]*\\)\"" 1 font-lock-string-face t)
-   '("<[^>=]*\\(href\\|src\\)[ \t\n]*=[ \t\n]*\"\\([^\"]*\\)\"" 
+   '("<[^>=]*\\(href\\|src\\)[ \t\n]*=[ \t\n]*\"\\([^\"]*\\)\""
      2 font-lock-string-face t))
   "Subdued level highlighting for hm--html-mode."
   :group 'hm--html-display
@@ -900,8 +900,8 @@ Look at the description of the variable idd-actions."
   (append hm--html-font-lock-keywords-1
 	  (list
 	   '(">\\([^<]+\\)</a>" 1 font-lock-reference-face)
-	   '("</b>\\([^<]+\\)</b>" 1 bold)
-	   '("</i>\\([^<]+\\)</i>" 1 italic)
+	   '("<b>\\([^<]+\\)</b>" 1 bold)
+	   '("<i>\\([^<]+\\)</i>" 1 italic)
 	   ))
   "Gaudy level highlighting for hm--html-mode."
   :group 'hm--html-display
@@ -952,7 +952,7 @@ Look at the description of the variable idd-actions."
 
 
 ;;; For the file html-view.el
-;;; There are also some other variables in hmtl-view.el
+;;; There are also some other variables in html-view.el
 ;;; Look at that file, if you've trouble with the functions
 ;;; to preview the html document with the Mosaic
 (defcustom html-view-mosaic-command "/sol/www/bin/mosaic"
@@ -963,9 +963,9 @@ Look at the description of the variable idd-actions."
 		 file))
 
 (defcustom html-sigusr1-signal-value 16
-  "Value for the SIGUSR1 signal on your system.  
+  "Value for the SIGUSR1 signal on your system.
 See, usually, /usr/include/sys/signal.h.
- 	SunOS 4.1.x	: (setq html-sigusr1-signal-value 30)
+	SunOS 4.1.x	: (setq html-sigusr1-signal-value 30)
 	SunOS 5.x	: (setq html-sigusr1-signal-value 16)
 	Linux		: (setq html-sigusr1-signal-value 10))"
   :group 'hm--html-display
@@ -1263,4 +1263,3 @@ Use lower case characters in this list!!!!"
 
 ;;; Announce the feature hm--html-configuration
 (provide 'hm--html-configuration)
-
