@@ -1,11 +1,11 @@
 ;;; jde-help.el
-;; $Revision: 1.64 $ 
+;; $Revision: 1.72 $ 
 
 ;; Author: Paul Kinnucan <paulk@mathworks.com>, Phillip Lord <plord@hgmp.mrc.ac.uk>
 ;; Maintainer: Paul Kinnucan
 ;; Keywords: java, tools
 
-;; Copyright (C) 1999, 2001, 2002, 2003 Paul Kinnucan.
+;; Copyright (C) 1999, 2001, 2002, 2003, 2004 Paul Kinnucan.
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -114,6 +114,47 @@ which is included in the Emacs w3 package."
 	       (autoload 'url-file-exists "url" nil nil nil))
 	  (set-default sym val)))
 
+;; (makunbound 'jde-help-wget-tries)
+(defcustom jde-help-wget-tries nil
+  "Specifies the number of times that the JDEE should try getting
+documentation from a remote site This option applies only if wget is
+the`jde-help-remote-file-exists-function'. It sets wget's --tries 
+command-line option. It is helpful in situations where
+one of the the sites in `jde-help-docsets' is not always reachable."
+  :group 'jde-project
+  :type '(choice (const :tag "Try once" :value nil)
+		 (const :tag "Never stop trying" :value 0)
+                 (integer :tag "Number of retries" :value 1)))
+
+;; (makunbound 'jde-help-wget-timeout)
+(defcustom jde-help-wget-timeout nil
+  "Specifies the length of time that the JDEE should wait for a remote site
+to respond to a request for a document. This option applies only if wget is
+the`jde-help-remote-file-exists-function'. It sets wget's --timeout 
+command-line option. It is helpful in situations where
+one of the the sites in `jde-help-docsets' is not always reachable."
+  :group 'jde-project
+  :type '(choice (const :tag "Default (900 s.)" :value nil)
+		 (const :tag "Disable timeout checking" :value 0)
+                 (integer :tag "Timeout (seconds)" :value 900)))
+
+(defcustom jde-help-wget-command-line-options nil
+  "Specifies additional options (beyond --spider, --tries and
+--timeout) to pass to wget, if wget is used for
+`jde-help-remote-file-exists-function'."
+  :group 'jde-project
+  :type 'string)
+
+;; (makunbound 'jde-help-browser-function)
+(defcustom jde-help-browser-function "browse-url"
+  "Specifies the function that the JDEE uses to display
+HTML pages."
+  :group 'jde-project
+  :type '(choice
+	  (const :tag "browse-url" :value "browse-url")
+	  (const :tag "w3m-browse-url" :value "w3m-browse-url")
+	  (function :tag "Other" :value identity)))
+
 
 (defun jde-file-to-url (file)
   "Convert FILE path to a URL. If FILE is a DOS path, this
@@ -124,11 +165,11 @@ a drive specifier with a colon."
   (if (or (string-match "http:" file)
 	  (string-match "file:" file))
       file
-    (format "file://localhost/%s"
+    (format "file://localhost%s"
 	    (let ((file (jde-convert-cygwin-path file)))
 	      ;; Check for DOS path.
 	      (if (string-match "[a-zA-Z]:" file)
-		  (substitute ?| ?: file)
+		  (concat "/" (substitute ?| ?: file))
 		file)))))
 
 
@@ -171,7 +212,13 @@ to verify the existence of pages located on remote systems."
                  (string-match
                   "200"
                   (shell-command-to-string
-                   (concat "wget --spider " url))))
+                   (concat "wget --spider "
+			   (if jde-help-wget-tries
+			       (concat "--tries=" jde-help-wget-tries))
+			   (if jde-help-wget-timeout
+			       (concat "--timeout=" jde-help-wget-timeout))
+			   jde-help-wget-command-line-options
+			   " " url))))
                 (setq url nil))
           (error
            (concat "Cannot find wget. This utility is needed "
@@ -285,9 +332,17 @@ documented."
      (message "%s" (error-message-string err)))))
   
 
-(defun jde-help-show-document (doc-file)
-  "Displays DOC-FILE in the default browser."
-  (browse-url (jde-file-to-url doc-file)))
+(defun jde-help-show-document (doc-url &rest args)
+  "Displays DOC-URL in the browser specified by `jde-help-browser-function'."
+  (let ((browser-function
+	 (cond
+	  ((functionp jde-help-browser-function)
+	   jde-help-browser-function)
+	  ((string= jde-help-browser-function "w3m-browse-url")
+	   'w3m-browse-url)
+	  (t
+	   'browse-url))))
+  (apply browser-function doc-url args)))
 
 (defun jde-help-parse-symbol-at-point ()
   "Returns (cons TYPE MEMBER) where TYPE is the declared type of
@@ -324,59 +379,64 @@ field or method referenced by the name if qualified."
 
 
 (defun jde-help-show-class-member-doc (docfile &optional member)
-  "Show DOCFILE in the browser defined by `browse-url-browser-function'
+  "Show DOCFILE in the browser defined by `jde-help-browser-function'
 where DOCFILE is the class and MEMBER is the anchor for a class
-member. This function creates a temporary HTML file that redirects the
+member. If the `jde-help-browser-function' is is not w3m-browse-url, 
+this function creates a temporary HTML file that redirects the
 browser to DOCFILE. This is a workaround made necessary by the fact
 that the default browser function for Windows uses the Windows
 ShellExecute function to invoke Internet Explorer and for some reason
-ShellExecute does not pass the anchor to IE."
-  (let* ((temp-directory (jde-temp-directory))
-	 (metafile (expand-file-name "jde_meta.html" temp-directory))
-	 (buff (find-file-noselect metafile nil t))
-	 (standard-output buff)
-         (pos (string-match "[^/]*$" docfile))
-         (root (jde-help-get-root-dir docfile))
-         (anchor (if member (concat docfile "#" member)
-                   docfile)))
-    (if buff
-	(save-excursion
-	  (set-buffer buff)
-	  (erase-buffer)
-          (if jde-help-use-frames
-              (progn
-                (princ "<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.01 Frameset//EN\" \"http://www.w3.org/TR/html4/frameset.dtd\">\n")
-                (princ "<html>\n<head>\n")
-                (princ "<title>JDE javadoc window</title>\n</head>\n")
-                (princ "<frameset cols=\"20%,80%\" onload=\"window.focus()\">\n")
-                (princ "<frameset rows=\"30%,70%\">\n")
-                (princ 
-                 (format "<frame src=\"%soverview-frame.html\" name=\"packageListFrame\">\n"
-                         root))
-                (princ
-                 (format "<frame src=\"%spackage-frame.html\" name=\"packageFrame\">\n"
-                         (substring docfile 0 pos)))
-                (princ 
-                 (format "<frame src=\"%sallclasses-frame.html\" name=\"packageFrame\">\n"
-                         root))
-                (princ "</frameset>\n")
-                (princ
-                 (format "<frame src=\"%s\" name=\"classFrame\">\n"
-                         (jde-file-to-url anchor)))
-                (princ "</frameset>\n")
-                (princ "</html>\n"))
-            (progn
-              (princ "<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.01//EN\" \"http://www.w3.org/TR/html4/strict.dtd\">\n")
-              (princ "<html>\n<head>\n")
-              (princ 
-               (format "<meta http-equiv=\"Refresh\" content=\"0; URL=%s\">\n"
-                       (jde-file-to-url anchor)))
-              (princ "</head>\n<body onload=\"window.focus()\">\n</body>\n</html>")))
-	  (save-buffer)
-	  (kill-buffer buff)
-	  (jde-help-show-document metafile))
-      (error "Unable to create a temporary file in %s directory."
-	     temporary-file-directory))))
+ShellExecute does not pass the anchor to IE. If `jde-help-use-frames'
+is nonnil, this function creates a metafile that displays the 
+multiframe version of the standard Javadoc page."
+  (let* ((anchor (if member (concat docfile "#" member)
+		  docfile))
+	 (doc-url (jde-file-to-url anchor)))
+    (unless (string= jde-help-browser-function "w3m-browse-url")
+      (let* ((temp-directory (jde-temp-directory))
+	     (metafile (expand-file-name "jde_meta.html" temp-directory))
+	     (buff (find-file-noselect metafile nil t))
+	     (standard-output buff)
+	     (pos (string-match "[^/]*$" docfile))
+	     (root (jde-help-get-root-dir docfile)))
+	(if buff
+	    (progn
+	      (save-excursion
+		(set-buffer buff)
+		(erase-buffer)
+		(if jde-help-use-frames
+		    (progn
+		      (princ "<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.01 Frameset//EN\" \"http://www.w3.org/TR/html4/frameset.dtd\">\n")
+		      (princ "<html>\n<head>\n")
+		      (princ "<title>JDE javadoc window</title>\n</head>\n")
+		      (princ "<frameset cols=\"20%,80%\" onload=\"window.focus()\">\n")
+		      (princ "<frameset rows=\"30%,70%\">\n")
+		      (princ 
+		       (format "<frame src=\"%soverview-frame.html\" name=\"packageListFrame\">\n"
+			       root))
+		      (princ
+		       (format "<frame src=\"%spackage-frame.html\" name=\"packageFrame\">\n"
+			       (substring docfile 0 pos)))
+		      (princ 
+		       (format "<frame src=\"%sallclasses-frame.html\" name=\"packageFrame\">\n"
+			     root))
+		      (princ "</frameset>\n")
+		      (princ
+		       (format "<frame src=\"%s\" name=\"classFrame\">\n" doc-url))
+		      (princ "</frameset>\n")
+		      (princ "</html>\n"))
+		  (progn
+		    (princ "<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.01//EN\" \"http://www.w3.org/TR/html4/strict.dtd\">\n")
+		    (princ "<html>\n<head>\n")
+		    (princ 
+		     (format "<meta http-equiv=\"Refresh\" content=\"0; URL=%s\">\n"  doc-url))
+			     (princ "</head>\n<body onload=\"window.focus()\">\n</body>\n</html>")))
+		(save-buffer)
+		(kill-buffer buff))
+	      (setq doc-url metafile))
+	  (error "Unable to create a temporary file in %s directory."
+		 temporary-file-directory))))
+    (jde-help-show-document doc-url)))
 
 (defun jde-help-popup-class-member-menu (class &optional title)
   "Popup a menu of the fields and methods defined by CLASS.
@@ -390,11 +450,11 @@ Return the member selected by the user."
                    ;; if only one item match, return it 
                    (car classinfo)
                  
-                 (if (string-equal (car jde-complete-function)
-                                   "jde-complete-menu")
-                     ;; delegates menu handling to imenu :-)
+                 (if (eq jde-complete-function 'jde-complete-menu)
+                     ;; delegates menu handling to imenu :-) Popup window at
+                     ;; text cursor
                      (imenu--mouse-menu classinfo  
-                                        (jde-cursor-posn-as-event) ; Popup window at text cursor
+                                        (jde-cursor-posn-as-event) 
                                         (or title "Class Members"))
                    (assoc (completing-read (or title "Completion: ")
                                            classinfo)
@@ -442,7 +502,13 @@ for CLASS actually documents the selected class member."
 	     (executable-find (if (eq system-type 'windows-nt) "wget.exe" "wget"))
 	     (not (string-match "200"
 				(shell-command-to-string
-				 (concat "wget --spider " jde-jdk-doc-url))))))	
+				 (concat "wget --spider "
+					 (if jde-help-wget-tries
+					     (concat "--tries=" jde-help-wget-tries))
+					 (if jde-help-wget-timeout
+					     (concat "--timeout=" jde-help-wget-timeout))
+					 jde-help-wget-command-line-options
+					 " " jde-jdk-doc-url))))))	
 	(error "JDK doc does not exist at jde-jdk-doc-url value: %s" jde-jdk-doc-url))
     jde-jdk-doc-url)
    ((string-match "file://" jde-jdk-doc-url)
@@ -462,6 +528,17 @@ for CLASS actually documents the selected class member."
 	  path
 	(error "Cannot find JDK doc. Please set jde-jdk-directory or jde-jdk-doc-url"))))))
 
+;;;###autoload
+(defun jde-help-beanshell ()
+  "Displays the BeanShell documentation."
+  (interactive)
+    (browse-url 
+    "http://www.beanshell.org/manual/contents.html"
+     (if (boundp 
+ 	 'browse-url-new-window-flag)
+         browse-url-new-window-flag
+       browse-url-new-window-p)))
+
 ;;;###autoload
 (defun jde-help-browse-jdk-doc ()
   "Displays the JDK doc in a web browser. This function uses the URL
@@ -474,10 +551,38 @@ stored in the variable jde-jdk-doc-url to locate the JDK documentation."
        browse-url-new-window-flag
      browse-url-new-window-p)))
 
-
 (provide 'jde-help)
 
 ;; $Log: jde-help.el,v $
+;; Revision 1.72  2004/11/25 05:48:20  jslopez
+;; Fixes regression bug to jde-help-class-member caused by modification to
+;; jde-complete-function.
+;;
+;; Revision 1.71  2004/10/06 05:10:38  paulk
+;; Removed dead code.
+;;
+;; Revision 1.70  2004/10/06 05:07:43  paulk
+;; Fixes bug that caused generation of an extra slash in  URLs for local files on UNIX systems.
+;;
+;; Revision 1.69  2004/10/06 04:33:58  paulk
+;; Add jde-help-browser-function customization variable.
+;;
+;; Revision 1.68  2004/09/27 04:49:18  paulk
+;; Fix jde-help-show-class-member-doc so that it creates a metafile only
+;; if the user is using the default Windows browser, i.e., Internet
+;; Explorer. This change allows the JDEE to use w3m (specifically,
+;; w3m-browse-url) to display Javadoc.
+;;
+;; Revision 1.67  2004/08/25 12:28:33  paulk
+;; Add jde-help-beanshell.
+;;
+;; Revision 1.66  2004/08/01 11:59:04  paulk
+;; Fixed jde-help-show-class-member-doc to call jde-help-show-document from the JDEE buffer instead of the temp buffer to ensure that JDEE customizations are in effect, in particular, browse-url-browser-function. Thanks to Dan Katz.
+;;
+;; Revision 1.65  2004/03/04 04:43:31  paulk
+;; Adds the jde-help-wget-tries, jde-help-wget-timeout, and jde-help-wget-command-line-options
+;; variables. Thanks to Nick Sieger.
+;;
 ;; Revision 1.64  2003/08/28 05:18:15  paulk
 ;; Add jde-help-get-jdk-doc-url function.
 ;;
