@@ -1,12 +1,12 @@
 ;;; jde-imenu.el --- imenu setup for the JDE
-;; $Revision: 1.6 $ 
+;; $Revision: 1.7 $ 
 
 ;; Author: Paul Kinnucan <paulk@mathworks.com>,
 ;;         David Ponce <david@dponce.com>
 ;; Maintainer: Paul Kinnucan, David Ponce
 ;; Keywords: java, tools
 
-;; Copyright (C) 2000, 2001, 2002 Paul Kinnucan.
+;; Copyright (C) 2000, 2001, 2002, 2004 Paul Kinnucan.
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -154,8 +154,8 @@ association are not displayed (see also `jde-imenu-include-modifiers')."
   "*If non-nil sorts items in the index menu.
 You can choose:
 
-- - 'asc   to sort by token name ascending (ignoring case).
-- - 'desc  to sort by token name descending (ignoring case).
+- - 'asc   to sort by tag name ascending (ignoring case).
+- - 'desc  to sort by tag name descending (ignoring case).
 
 Use *Rescan* to rebuild the imenu when you have changed this option."
   :group 'jde-project
@@ -207,49 +207,49 @@ also `jde-imenu-include-modifiers')."
 ;;;; Universal `semantic-imenu' stuff adapted to JDE's needs
 ;;;;
 
-(defun jde-imenu-prototype-nonterminal (token &optional parent color)
-  "Return a prototype for TOKEN.
+(defun jde-imenu-prototype-nonterminal (tag &optional parent color)
+  "Return a prototype for TAG.
 See also `semantic-prototype-nonterminal'."
-  (let* ((token-cat  (semantic-token-token token))
+  (let* ((tag-cat  (semantic-tag-class tag))
          (prototyper (intern-soft (format "jde-imenu-prototype-%s"
-                                          token-cat))))
+                                          tag-cat))))
     (if (fboundp prototyper)
-        (funcall prototyper token parent color)
-      (semantic-java-prototype-nonterminal token parent color))))
+        (funcall prototyper tag parent color)
+      (semantic-format-prototype-tag-java-mode tag parent color))))
 
-(defun jde-imenu-prototype-function (token &optional parent color)
-  "Return a function (method) prototype for TOKEN.
+(defun jde-imenu-prototype-function (tag &optional parent color)
+  "Return a function (method) prototype for TAG.
 See also `semantic-java-prototype-function'."
   (let ((sign (if jde-imenu-include-signature
-                  (semantic-java-prototype-function token parent color)
+                  (semantic-java-prototype-function tag parent color)
                 (concat (if color
-                            (semantic-colorize-text
-                             (semantic-token-name token) 'function)
-                          (semantic-token-name token))
+                            (semantic--format-colorize-text
+                             (semantic-tag-name tag) 'function)
+                          (semantic-tag-name tag))
                         "()"))))
     (concat (jde-imenu-abbreviate-modifiers
-             (semantic-token-function-modifiers token))
+             (semantic-tag-modifiers tag))
             sign)))
 
-(defun jde-imenu-prototype-variable (token &optional parent color)
-  "Return a variable (field) prototype for TOKEN.
+(defun jde-imenu-prototype-variable (tag &optional parent color)
+  "Return a variable (field) prototype for TAG.
 See also `semantic-java-prototype-variable'."
   (let ((sign (if jde-imenu-include-signature
-                  (semantic-java-prototype-variable token parent color)
+                  (semantic-java-prototype-variable tag parent color)
                 (if color
-                    (semantic-colorize-text
-                     (semantic-token-name token) 'variable)
-                  (semantic-token-name token)))))
+                    (semantic--format-colorize-text
+                     (semantic-tag-name tag) 'variable)
+                  (semantic-tag-name tag)))))
     (concat (jde-imenu-abbreviate-modifiers
-             (semantic-token-variable-modifiers token))
+             (semantic-tag-modifiers tag))
             sign)))
 
-(defun jde-imenu-prototype-type (token &optional parent color)
-  "Return a type (class/interface) prototype for TOKEN.
+(defun jde-imenu-prototype-type (tag &optional parent color)
+  "Return a type (class/interface) prototype for TAG.
 See also `semantic-prototype-nonterminal'."
-  (let ((sign (semantic-java-prototype-type token parent color)))
+  (let ((sign (semantic-java-prototype-type tag parent color)))
     (concat (jde-imenu-abbreviate-modifiers
-             (semantic-token-type-modifiers token))
+             (semantic-tag-modifiers tag))
             sign)))
 
 ;;;;
@@ -262,29 +262,29 @@ index to go to class definition."
   :group 'jde-project
   :type 'boolean)
 
-(defun jde-imenu-sort-tokens (tokens)
-  "Sorts the token list TOKENS depending on `jde-imenu-sort' value."
+(defun jde-imenu-sort-tags (tags)
+  "Sorts the tag list TAGS depending on `jde-imenu-sort' value."
   (cond ((eq jde-imenu-sort 'asc)
-         (sort tokens
+         (sort tags
                (function
-                (lambda (token1 token2)
-                  (string-lessp (upcase (semantic-token-name token1))
-                                (upcase (semantic-token-name token2)))))))
+                (lambda (tag1 tag2)
+                  (string-lessp (upcase (semantic-tag-name tag1))
+                                (upcase (semantic-tag-name tag2)))))))
         ((eq jde-imenu-sort 'desc)
-         (sort tokens
+         (sort tags
                (function
-                (lambda (token1 token2)
-                  (string-lessp (upcase (semantic-token-name token2))
-                                (upcase (semantic-token-name token1)))))))
+                (lambda (tag1 tag2)
+                  (string-lessp (upcase (semantic-tag-name tag2))
+                                (upcase (semantic-tag-name tag1)))))))
         (t
-         tokens)))
+         tags)))
 
-(defun jde-imenu-index-class  (class-token)
-  "Creates an imenu index for a class in CLASS-TOKEN."
-  (let* ((class-name  (semantic-token-name       class-token))
-         (class-type  (semantic-token-type       class-token))
-         (class-start (semantic-token-start      class-token))
-         (class-parts (semantic-token-type-parts class-token))
+(defun jde-imenu-index-class  (class-tag)
+  "Creates an imenu index for a class in CLASS-TAG."
+  (let* ((class-name  (semantic-tag-name       class-tag))
+         (class-type  (semantic-tag-type       class-tag))
+         (class-start (semantic-tag-start      class-tag))
+         (class-parts (semantic-tag-type-members class-tag))
          (class-index (jde-imenu-index-class-parts class-parts)))
 
     (if jde-imenu-include-classdef
@@ -301,32 +301,32 @@ index to go to class definition."
     (list (cons (format "%s %s" class-type class-name)
                 class-index))))
 
-(defun jde-imenu-index-class-parts (tokens)
-  "Creates an imenu index for class parts in TOKENS.
+(defun jde-imenu-index-class-parts (tags)
+  "Creates an imenu index for class parts in TAGS.
 When`jde-imenu-include-signature' is non-nil the
 index menu displays full method signatures and field types."
-  (let ((methods (semantic-find-nonterminal-by-token 'function tokens))
-        (fields  (semantic-find-nonterminal-by-token 'variable tokens))
-        (classes (semantic-find-nonterminal-by-token 'type     tokens))
+  (let ((methods (semantic-find-nonterminal-by-token 'function tags))
+        (fields  (semantic-find-nonterminal-by-token 'variable tags))
+        (classes (semantic-find-nonterminal-by-token 'type     tags))
         index)
 
-    (setq methods (jde-imenu-sort-tokens methods))
+    (setq methods (jde-imenu-sort-tags methods))
     (while methods
-      (let* ((method-token (car methods))
-             (method-name  (semantic-token-name method-token))
-             (method-pos   (semantic-token-start method-token))
+      (let* ((method-tag (car methods))
+             (method-name  (semantic-tag-name method-tag))
+             (method-pos   (semantic-tag-start method-tag))
              method-sig)
         (if jde-imenu-include-signature
-            (let ((method-type  (semantic-token-type method-token))
-                  (method-args  (semantic-token-function-args method-token)))
+            (let ((method-type  (semantic-tag-type method-tag))
+                  (method-args  (semantic-tag-function-arguments method-tag)))
               (setq method-sig (if method-type
                                    (format "%s %s(" method-type method-name)
                                  (format "%s(" method-name)))
               (while method-args
-                (let ((method-arg-token (car method-args))
+                (let ((method-arg-tag (car method-args))
                       method-arg-type)
-                  (when (semantic-token-p method-arg-token)
-                    (setq method-arg-type (semantic-token-type method-arg-token))
+                  (when (semantic-tag-p method-arg-tag)
+                    (setq method-arg-type (semantic-tag-type method-arg-tag))
                     (setq method-sig (concat method-sig method-arg-type ",")))
                   (setq method-args (cdr method-args))))
               ;; remove the extra comma at end
@@ -343,23 +343,23 @@ index menu displays full method signatures and field types."
     (if fields
         (setq index (append index '(("-"))))) 
     
-    (setq fields (jde-imenu-sort-tokens fields))
+    (setq fields (jde-imenu-sort-tags fields))
     (while fields
-      (let* ((field-token (car fields))
-             (field-name  (semantic-token-name  field-token))
-             (field-pos   (semantic-token-start field-token)))
+      (let* ((field-tag (car fields))
+             (field-name  (semantic-tag-name  field-tag))
+             (field-pos   (semantic-tag-start field-tag)))
         (if jde-imenu-include-signature
-            (setq field-name (concat (semantic-token-type field-token)
+            (setq field-name (concat (semantic-tag-type field-tag)
                                      " " field-name)))
         (setq index 
               (append 
                index (list (cons field-name field-pos)))))
       (setq fields (cdr fields)))
 
-    (setq classes (jde-imenu-sort-tokens classes))
+    (setq classes (jde-imenu-sort-tags classes))
     (while classes
-      (let* ((class-token  (car classes))
-             (class-index  (jde-imenu-index-class class-token)))
+      (let* ((class-tag  (car classes))
+             (class-index  (jde-imenu-index-class class-tag)))
         (setq index (append index class-index)))
       (setq classes (cdr classes)))
     index))
@@ -368,38 +368,38 @@ index menu displays full method signatures and field types."
   "Creates an imenu index for a Java source buffer.
 This function uses the semantic bovinator to index the buffer."
 
-    (semantic-bovinate-toplevel t)
+    (semantic-fetch-tags)
  
-    (let* ((tokens   (semantic-bovinate-toplevel))
-	   (packages (semantic-find-nonterminal-by-token 'package tokens))
-	   (depends  (semantic-find-nonterminal-by-token 'include tokens))
-	   (classes  (semantic-find-nonterminal-by-token 'type tokens))
+    (let* ((tags   (semantic-fetch-tags))
+	   (packages (semantic-find-nonterminal-by-token 'package tags))
+	   (depends  (semantic-find-nonterminal-by-token 'include tags))
+	   (classes  (semantic-find-nonterminal-by-token 'type tags))
 	   depend-index
 	   index)
 
 
-      (setq classes (jde-imenu-sort-tokens classes))
+      (setq classes (jde-imenu-sort-tags classes))
       (while classes
-	(let* ((class-token  (car classes))
-	       (class-index  (jde-imenu-index-class class-token)))
+	(let* ((class-tag  (car classes))
+	       (class-index  (jde-imenu-index-class class-tag)))
 	  (setq index (append index class-index)))
 	(setq classes (cdr classes)))
 
-      (setq depends (jde-imenu-sort-tokens depends))
+      (setq depends (jde-imenu-sort-tags depends))
       (while depends
-	(let* ((depend-token (car depends))
-	       (depend-name  (semantic-token-name  depend-token))
-	       (depend-pos   (semantic-token-start depend-token)))
+	(let* ((depend-tag (car depends))
+	       (depend-name  (semantic-tag-name  depend-tag))
+	       (depend-pos   (semantic-tag-start depend-tag)))
 	  (setq depend-index (append depend-index (list (cons depend-name depend-pos)))))
 	(setq depends (cdr depends)))
       (if depend-index
 	  (setq index (append index (list (cons "imports" depend-index)))))
 
-      (setq packages (jde-imenu-sort-tokens packages))
+      (setq packages (jde-imenu-sort-tags packages))
       (while packages
-	(let* ((package-token (car packages))
-	       (package-name  (semantic-token-name  package-token))
-	       (package-pos   (semantic-token-start package-token)))
+	(let* ((package-tag (car packages))
+	       (package-name  (semantic-tag-name  package-tag))
+	       (package-pos   (semantic-tag-start package-tag)))
 	  (setq index 
 		(append 
 		 index 
@@ -436,6 +436,10 @@ This function uses the semantic bovinator to index the buffer."
 (provide 'jde-imenu)
 
 ;; $Log: jde-imenu.el,v $
+;; Revision 1.7  2004/07/06 05:25:51  paulk
+;; Convert to new tag nomenclature used by semantic 2.0 to avoid
+;; byte-compilation errors caused by references to obsolete names.
+;;
 ;; Revision 1.6  2003/09/21 03:35:37  paulk
 ;; (jde-imenu-setup): Install correct override for Semantic 2.0. Submitted by David Ponce.
 ;;
