@@ -149,7 +149,9 @@ Match RE and if successful, execute MATCHES."
      (and
       (cvs-match ".*$")
       (cvs-create-fileinfo 'MESSAGE cvs-current-dir " "
-			   (concat " Parser Error: '" (cvs-parse-msg) "'")
+			   ;; (concat " Parser Error: '"
+			   (cvs-parse-msg)
+			   ;; "'")
 			   :subtype 'ERROR)))))
 
 
@@ -428,6 +430,7 @@ The remaining KEYS are passed directly to `cvs-create-fileinfo'."
       (cvs-match " *Repository revision:[ \t]*\\([0-9.]+\\)[ \t]*\\(.*\\)$"
 		 (head-rev 1))
       (cvs-match " *Repository revision:.*"))
+     (cvs-or (cvs-match " *Commit Identifier:[ \t]*\\(.*\\)$") t) ; alioth cvs
      (cvs-or
       (and;;sometimes those fields are missing
        (cvs-match " *Sticky Tag:[ \t]*\\(.*\\)$") ; FIXME: use it
