@@ -1009,21 +1009,6 @@ See `after-change-functions' for the meaning of BEG, END and LEN."
 	(diff-fixup-modifs (point) (cdr diff-unhandled-changes))))
     (setq diff-unhandled-changes nil)))
 
-;; XEmacs change: no autoload for this for the transition period
-(defadvice vc-backend-diff (around diff-mode-vc activate)
-  ;; BEWARE!! when this is autoloaded, CL might not be available
-  (condition-case ()
-      (with-current-buffer "*vc-diff*" (setq buffer-read-only nil))
-    (error nil))
-  ad-do-it
-  (condition-case ()
-      (with-current-buffer "*vc-diff*"
-        (if (or (eq major-mode default-major-mode)
-                (memq major-mode '(fundamental-mode text-mode diff-mode)))
-            (diff-mode))
-        (if (eq major-mode 'diff-mode) (font-lock-mode)))
-    (error nil)))
-
 
 ;;;; 
 ;;;; The main function
