@@ -172,6 +172,22 @@ Set by \\[tex-region], \\[tex-buffer], and \\[tex-file].")
 (defvar tex-mode-syntax-table nil
   "Syntax table used while in TeX mode.")
 
+(defvar tex-mode-hook nil
+  "Hook to run in TeX modes (plain-tex-mode, latex-mode, slitex-mode).")
+
+(defvar tex-shell-hook nil
+  "Hook to run in TeX modes (plain-tex-mode, latex-mode, slitex-mode),
+when the special subshell is initiated.")
+
+(defvar plain-tex-mode-hook nil
+  "Hook to run when entering plain-tex-mode.")
+
+(defvar latex-mode-hook nil
+  "Hook to run when entering latex-mode.")
+
+(defvar slitex-mode-hook nil
+  "Hook to run when entering slitex-mode.")
+
 (defun tex-define-common-keys (keymap)
   "Define the keys that we want defined both in TeX mode and in the tex-shell."
   (define-key keymap "\C-c\C-k" 'tex-kill-job)
@@ -868,4 +884,9 @@ Runs the shell command defined by tex-show-queue-command."
 
 (run-hooks 'tex-mode-load-hook)
 
+;; XEmacs additions
+;;;###autoload(add-to-list 'auto-mode-alist '("\\.ltx\\'" . latex-mode))
+;;;###autoload(add-to-list 'auto-mode-alist '("\\.[tT]e[xX]\\'" . tex-mode))
+;;;###autoload(add-to-list 'auto-mode-alist '("\\.\\(?:sty\\|cls\\|bbl\\)\\'" . latex-mode))
+
 (provide 'tex-mode)
