@@ -1,22 +1,23 @@
-;;; Summary gathering and formatting routines for VM
-;;; Copyright (C) 1989-1995, 2000 Kyle E. Jones
-;;;
-;;; This program is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 1, or (at your option)
-;;; any later version.
-;;;
-;;; This program is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-;;(provide 'vm-summary)
+;;; vm-summary.el --- Summary gathering and formatting routines for VM
+;;
+;; Copyright (C) 1989-1995, 2000 Kyle E. Jones
+;; Copyright (C) 2003-2006 Robert Widhopf-Fenk
+;;
+;; This program is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2 of the License, or
+;; (at your option) any later version.
+;;
+;; This program is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;;
+;; You should have received a copy of the GNU General Public License along
+;; with this program; if not, write to the Free Software Foundation, Inc.,
+;; 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
+;;; Code:
 (defun vm-summary-mode-internal ()
   (setq mode-name "VM Summary"
 	major-mode 'vm-summary-mode
@@ -51,9 +52,10 @@
 (fset 'vm-summary-mode 'vm-mode)
 (put 'vm-summary-mode 'mode-class 'special)
 
+;;;###autoload
 (defun vm-summarize (&optional display raise)
-  "Summarize the contents of the folder in a summary buffer. 
-The format is as described by the variable vm-summary-format.  Generally
+  "Summarize the contents of the folder in a summary buffer.
+The format is as described by the variable `vm-summary-format'.  Generally
 one line per message is most pleasing to the eye but this is not
 mandatory."
   (interactive "p\np")
@@ -95,6 +97,7 @@ mandatory."
 		(list this-command)))
   (vm-update-summary-and-mode-line))
 
+;;;###autoload
 (defun vm-summarize-other-frame (&optional display)
   "Like vm-summarize, but run in a newly created frame."
   (interactive "p")
@@ -441,10 +444,10 @@ mandatory."
 				   new-match-end (car retval))))
 		       (setq token `('group-begin
 				     ,(if (match-beginning 2)
-					  (string-to-int
+					  (string-to-number
 					   (concat (match-string 1 format)
 						   (match-string 2 format))))
-				     ,(string-to-int
+				     ,(string-to-number
 				       (match-string 4 format)))
 			     splice t)))
 		    ((= conv-spec ?\))
@@ -544,7 +547,7 @@ mandatory."
 				  'vm-numeric-left-justify-string
 				'vm-left-justify-string)
 			      (car sexp)
-			      (string-to-int
+			      (string-to-number
 			       (substring format
 					  (match-beginning 2)
 					  (match-end 2))))))
@@ -555,14 +558,14 @@ mandatory."
 				  'vm-numeric-right-justify-string
 				'vm-right-justify-string)
 			      (car sexp)
-			      (string-to-int
+			      (string-to-number
 			       (substring format
 					  (match-beginning 2)
 					  (match-end 2)))))))
 	      (cond ((and (not token) (match-beginning 3))
 		     (setcar sexp
 			     (list 'vm-truncate-string (car sexp)
-				   (string-to-int
+				   (string-to-number
 				    (substring format
 					       (match-beginning 4)
 					       (match-end 4)))))))
@@ -731,6 +734,18 @@ mandatory."
 	(- (vm-text-end-of (vm-real-message-of m))
 	   (vm-text-of (vm-real-message-of m)))))))
 
+(defun vm-su-spam-score-aux (m)
+  "Return the numeric spam level for M."
+  (let ((spam-status (vm-get-header-contents m "X-Spam-Status:")))
+    (if (string-match "hits=\\([+-]?[0-9.]+\\)" spam-status)
+        (string-to-number (match-string 1 spam-status))
+      0)))
+
+(defun vm-su-spam-score (m)
+  "Return the numeric spam level for M (possibly using cache)."
+  (or (vm-spam-score-of m)
+      (vm-set-spam-score-of m (vm-su-spam-score-aux m))))
+
 (defun vm-su-weekday (m)
   (or (vm-weekday-of m)
       (progn (vm-su-do-date m) (vm-weekday-of m))))
@@ -821,7 +836,7 @@ mandatory."
 		  (<= (length string) 2))
 	     (setq monthday string))
 	    ((= (length string) 2)
-	     (if (< (string-to-int string) 70)
+	     (if (< (string-to-number string) 70)
 		 (setq year (concat "20" string))
 	       (setq year (concat "19" string))))
 	    (t (setq year string))))
@@ -1051,7 +1066,8 @@ mandatory."
 		 (vm-get-header-contents m "Newsgroups:" ", ")
 		 ;; desperation....
 		 (user-login-name))
-	  cc (vm-get-header-contents m "Cc:" ", ")
+          cc (or (vm-get-header-contents m "Cc:" ", ")
+                 (vm-get-header-contents m "Bcc:" ", "))
 	  all to
 	  all (if all (concat all ", " cc) cc)
 	  addresses (rfc822-addresses all))
@@ -1069,7 +1085,8 @@ mandatory."
 	(aset full-name i ?\ ))
       (setq names (cons full-name names))
       (setq list (cdr list)))
-    (setq names (nreverse names)) ; added by jwz for fixed vm-parse-addresses
+    (setq names (nreverse names))
+    ;; added by jwz for fixed vm-parse-addresses
     (vm-set-to-of m (mapconcat 'identity addresses ", "))
     (vm-set-to-names-of m (mapconcat 'identity names ", "))))
 
@@ -1117,7 +1134,8 @@ mandatory."
   (or (vm-subject-of m)
       (vm-set-subject-of
        m
-       (let ((subject (or (vm-get-header-contents m "Subject:" " ") ""))
+       (let ((subject (vm-decode-mime-encoded-words-in-string
+                       (or (vm-get-header-contents m "Subject:") "")))
 	     (i nil))
 	 (while (string-match "\n[ \t]*" subject)
 	   (setq subject (replace-match " " nil t subject)))
@@ -1137,7 +1155,10 @@ mandatory."
 	  (vm-set-summary-of m (vm-summary-sprintf vm-summary-format m t))
 	  (vm-summary-of m)))))
 
+;;;###autoload
 (defun vm-fix-my-summary!!! ()
+  "Rebuilts the summary.
+Call this function if you made changes to `vm-summary-format'."
   (interactive)
   (vm-select-folder-buffer)
   (vm-check-for-killed-summary)
@@ -1411,7 +1432,7 @@ mandatory."
 				  'vm-numeric-left-justify-string
 				'vm-left-justify-string)
 			      (car sexp)
-			      (string-to-int
+			      (string-to-number
 			       (substring format
 					  (match-beginning 2)
 					  (match-end 2))))))
@@ -1422,14 +1443,14 @@ mandatory."
 				  'vm-numeric-right-justify-string
 				'vm-right-justify-string)
 			      (car sexp)
-			      (string-to-int
+			      (string-to-number
 			       (substring format
 					  (match-beginning 2)
 					  (match-end 2)))))))
 	      (cond ((match-beginning 3)
 		     (setcar sexp
 			     (list 'vm-truncate-string (car sexp)
-				   (string-to-int
+				   (string-to-number
 				    (substring format
 					       (match-beginning 4)
 					       (match-end 4)))))))
@@ -1700,3 +1721,5 @@ mandatory."
       nil )))
 
 (provide 'vm-summary)
+
+;;; vm-summary.el ends here
