@@ -1,22 +1,25 @@
-;;; Virtual folders for VM
-;;; Copyright (C) 1990-1997 Kyle E. Jones
-;;;
-;;; This program is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 1, or (at your option)
-;;; any later version.
-;;;
-;;; This program is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+;;; vm-virtual.el --- Virtual folders for VM
+;;
+;; Copyright (C) 1990-1997 Kyle E. Jones
+;; Copyright (C) 2003-2006 Robert Widhopf-Fenk
+;;
+;; This program is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2 of the License, or
+;; (at your option) any later version.
+;;
+;; This program is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;;
+;; You should have received a copy of the GNU General Public License along
+;; with this program; if not, write to the Free Software Foundation, Inc.,
+;; 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-;;(provide 'vm-virtual)
+;;; Code:
 
+;;;###autoload
 (defun vm-build-virtual-message-list (new-messages &optional dont-finalize)
   "Builds a list of messages matching the virtual folder definition
 stored in the variable vm-virtual-folder-definition.
@@ -113,12 +116,16 @@ all the real folder buffers involved."
 			 ;; set enable-local-variables to nil
 			 ;; for newer Emacses
 			 (let ((inhibit-local-variables t)
+                               (coding-system-for-read
+                                (vm-binary-coding-system))
 			       (enable-local-eval nil)
 			       (enable-local-variables nil))
 			   (find-file-noselect folder)))))
 	    (set-buffer (or (and (bufferp folder) folder)
 			    (vm-get-file-buffer folder)
 			    (let ((inhibit-local-variables t)
+                                  (coding-system-for-read
+                                   (vm-binary-coding-system))
 				  (enable-local-eval nil)
 				  (enable-local-variables nil))
 			      (find-file-noselect folder))))
@@ -248,6 +255,7 @@ all the real folder buffers involved."
 	  (setq vm-message-list new-message-list))
 	new-message-list ))))
 
+;;;###autoload
 (defun vm-create-virtual-folder (selector &optional arg read-only name
 					  bookmark)
   "Create a new virtual folder from messages in the current folder.
@@ -287,6 +295,7 @@ Prefix arg means the new virtual folder should be visited read only."
       (vm-menu-install-known-virtual-folders-menu)))
 
 
+;;;###autoload
 (defun vm-apply-virtual-folder (name &optional read-only)
   "Apply the selectors of a named virtual folder to the current folder
 and create a virtual folder containing the selected messages.
@@ -324,6 +333,7 @@ Prefix arg means the new virtual folder should be visited read only."
   (if vm-use-menus
       (vm-menu-install-known-virtual-folders-menu)))
 
+;;;###autoload
 (defun vm-create-virtual-folder-same-subject ()
   (interactive)
   (vm-follow-summary-cursor)
@@ -343,6 +353,7 @@ Prefix arg means the new virtual folder should be visited read only."
      'sortable-subject subject nil
      (format "%s %s %s" (buffer-name) 'subject displayed-subject) bookmark)))
 
+;;;###autoload
 (defun vm-create-virtual-folder-same-author ()
   (interactive)
   (vm-follow-summary-cursor)
@@ -411,8 +422,9 @@ Prefix arg means the new virtual folder should be visited read only."
 	   (if vm-virtual-mirror "mirrors" "does not mirror")
 	   (if (cdr vm-real-buffers) "s" "")))
 
+;;;###autoload
 (defun vm-virtual-help ()
-  (interactive)
+(interactive)
   (vm-display nil nil '(vm-virtual-help) '(vm-virtual-help))
   (message "VV = visit, VX = apply selectors, VC = create, VM = toggle virtual mirror"))
 
@@ -496,16 +508,16 @@ Prefix arg means the new virtual folder should be visited read only."
       (re-search-forward arg (vm-text-end-of (vm-real-message-of m)) t))))
 
 (defun vm-vs-more-chars-than (m arg)
-  (> (string-to-int (vm-su-byte-count m)) arg))
+  (> (string-to-number (vm-su-byte-count m)) arg))
 
 (defun vm-vs-less-chars-than (m arg)
-  (< (string-to-int (vm-su-byte-count m)) arg))
+  (< (string-to-number (vm-su-byte-count m)) arg))
 
 (defun vm-vs-more-lines-than (m arg)
-  (> (string-to-int (vm-su-line-count m)) arg))
+  (> (string-to-number (vm-su-line-count m)) arg))
 
 (defun vm-vs-less-lines-than (m arg)
-  (< (string-to-int (vm-su-line-count m)) arg))
+  (< (string-to-number (vm-su-line-count m)) arg))
 
 (defun vm-vs-virtual-folder-member (m)
   (vm-virtual-messages-of m))
@@ -535,6 +547,7 @@ Prefix arg means the new virtual folder should be visited read only."
 (defun vm-vs-unmarked (m) (not (vm-mark-of m)))
 (defun vm-vs-unedited (m) (not (vm-edited-flag m)))
 
+(put 'sexp 'vm-virtual-selector-clause "matching S-expression selector")
 (put 'header 'vm-virtual-selector-clause "with header matching")
 (put 'label 'vm-virtual-selector-clause "with label of")
 (put 'text 'vm-virtual-selector-clause "with text matching")
@@ -553,6 +566,7 @@ Prefix arg means the new virtual folder should be visited read only."
      "with less characters than")
 (put 'more-lines-than 'vm-virtual-selector-clause "with more lines than")
 (put 'less-lines-than 'vm-virtual-selector-clause "with less lines than")
+(put 'sexp 'vm-virtual-selector-arg-type 'string)
 (put 'header 'vm-virtual-selector-arg-type 'string)
 (put 'label 'vm-virtual-selector-arg-type 'label)
 (put 'text 'vm-virtual-selector-arg-type 'string)
@@ -568,6 +582,7 @@ Prefix arg means the new virtual folder should be visited read only."
 (put 'more-lines-than 'vm-virtual-selector-arg-type 'number)
 (put 'less-lines-than 'vm-virtual-selector-arg-type 'number)
 
+;;;###autoload
 (defun vm-read-virtual-selector (prompt)
   (let (selector (arg nil))
     (setq selector
@@ -592,12 +607,20 @@ Prefix arg means the new virtual folder should be visited read only."
 			      vm-label-obarray)
 			     nil)))))
 	      (t (setq arg (read-string prompt))))))
-    (or (fboundp (intern (concat "vm-vs-" (symbol-name selector))))
-	(error "Invalid selector"))
-    (list selector arg)))
+    (let ((real-selector
+	   (if (eq selector 'sexp)
+	       (let ((read-arg (read arg)))
+		 (if (listp read-arg) read-arg (list read-arg)))
+	     (list selector arg))))
+      (or (fboundp (intern (concat "vm-vs-"
+				   (symbol-name (car real-selector)))))
+	  (error "Invalid selector"))
+      real-selector)))
+
 
 ;; clear away links between real and virtual folders when
 ;; a vm-quit is performed in either type folder.
+;;;###autoload
 (defun vm-virtual-quit ()
   (save-excursion
     (cond ((eq major-mode 'vm-virtual-mode)
@@ -688,6 +711,7 @@ Prefix arg means the new virtual folder should be visited read only."
 		 (vm-update-summary-and-mode-line))
 	       (setq bp (cdr bp))))))))
 
+;;;###autoload
 (defun vm-virtual-save-folder (prefix)
   (save-excursion
     ;; don't trust blindly, user might have killed some of
@@ -702,6 +726,7 @@ Prefix arg means the new virtual folder should be visited read only."
   (vm-clear-modification-flag-undos)
   (vm-update-summary-and-mode-line))
 
+;;;###autoload
 (defun vm-virtual-get-new-mail ()
   (save-excursion
     ;; don't trust blindly, user might have killed some of
@@ -723,6 +748,7 @@ Prefix arg means the new virtual folder should be visited read only."
 	(setq bp (cdr bp)))))
   (vm-emit-totals-blurb))
 
+;;;###autoload
 (defun vm-make-virtual-copy (m)
   (widen)
   (let ((virtual-buffer (current-buffer))
@@ -755,5 +781,9 @@ Prefix arg means the new virtual folder should be visited read only."
 					 (vm-start-of real-m))))
     (set-marker (vm-end-of m) (+ (vm-start-of m) (- (vm-end-of real-m)
 						    (vm-start-of real-m))))))
-
 (provide 'vm-virtual)
+
+;; now load vm-avirtual to avoid a loading loop
+(require 'vm-avirtual)
+
+;;; vm-virtual.el ends here
