@@ -66,7 +66,7 @@
   (autoload 'easy-mmode-define-keymap "easy-mmode")
   (autoload 'ad-add-advice "advice"))
 
-(require 'tree-widget)
+(require 'jde-tree-widget)
 (require 'xetla)
 
 (defvar xetla-browse-buffer-name "*xetla-browse*")
